@@ -1,6 +1,8 @@
 import re
 
 FMS_BASE_URL = "https://findmestore.thinkr.jp"
+BREAK_TIME = 2
+RETRY_PERIOD = 30
 
 
 def fix_json(json_str: str) -> str:
